/* ========================================
 *
 * Copyright YOUR COMPANY, THE YEAR
 * All Rights Reserved
 * UNPUBLISHED, LICENSED SOFTWARE.
 *
 * CONFIDENTIAL AND PROPRIETARY INFORMATION
 * WHICH IS THE PROPERTY OF your company.
 *
 * ========================================
*/
#include "project.h"
#include <stdio.h>
#include <common.h>


#define OFFSET 2.04
#define LONGITUD 500

/* Add an explicit reference to the floating point printf library to allow
the usage of floating point conversion specifier */


#if defined (__GNUC__)
    asm (".global _printf_float");
#endif

float y[LONGITUD];
uint16 datos[LONGITUD]; 
float flag=0.0;
uint8 flag_r = 0u;
uint8 val8;
uint16 val;
uint8 errorStatus = 0u;
uint k, j;

/* Variable declarations for DMA_1 */
 uint8 DMA_1_Chan;
 uint8 DMA_1_TD[1] = {0};

CY_ISR(Adquisicion);
CY_ISR(RxIsr);


void my_Start(void);
void DMA_Config(void);


/* DMA Configuration constants for DMA_1 
Se configura el DMA para que transfiera dos bytes por cada burst
y una transacción. La transferencia se hace del ADC a memoria 
transfieriendo 2*longitud del vector
*/

#define DMA_1_BYTES_PER_BURST (2u)
#define DMA_1_REQUEST_PER_BURST (1u)
#define DMA_1_SRC_BASE (CYDEV_PERIPH_BASE)
#define DMA_1_DST_BASE (CYDEV_SRAM_BASE)


int main(void)
{     
    my_Start();         /*Rutina para inicializar los componentes*/
     /* Configure DMA to transfer ADC output to Memory*/
    DMA_Config();        
    
    //Punteros a la rutinas de interrupción  
    #if(INTERRUPT_CODE_ENABLED == ENABLED)
    isr_1_StartEx(Adquisicion);    
    isr_rx_StartEx(RxIsr);
    #endif /* INTERRUPT_CODE_ENABLED == ENABLED */
    
    CyDelay(50);  
    CyGlobalIntEnable; /* Enable global interrupts. */
    isr_rx_Enable();
    isr_1_Disable();
    
    /* Place your initialization/startup code here (e.g. MyInst_Start()) */
    for(;;) 
    {
        if (flag_r =='1')
        {   
            //Cuando se recibe una "I" por el puerto serial
            //Se inicializa una nueva adquisición de datos
            flag_r = '0'; 
            //Se habilita la digitalización y la INT 1    
            ADC_SAR_1_Start();
            isr_1_Enable();
       
            if (flag==1)
            {
                flag = 0;   
                
                for(j=0; j<(sizeof(y)/sizeof(y[0])); j++)
                {
                y[j] = ADC_SAR_1_CountsTo_Volts(datos[j]); 
                printf("%f\r\n", y[j]);
                }
            }
        
        }
    }
}    

void my_Start(){
//Se incializan los componentes
    ADC_SAR_Seq_1_Start();
    Clock_1_Start();
    Opamp_1_Start();
    Opamp_2_Start();
    PGA_1_Start();
//Se inicializa el puerto serial    
    UART_Start();  
    ADC_SAR_Seq_1_Stop();
}



void DMA_Config()
{
 
/* DMA Configuration for DMA_1 */
DMA_1_Chan = DMA_1_DmaInitialize(DMA_1_BYTES_PER_BURST, DMA_1_REQUEST_PER_BURST, 
    HI16(DMA_1_SRC_BASE), HI16(DMA_1_DST_BASE));
DMA_1_TD[0] = CyDmaTdAllocate();
CyDmaTdSetConfiguration(DMA_1_TD[0], 2*LONGITUD, CY_DMA_DISABLE_TD, DMA_1__TD_TERMOUT_EN | CY_DMA_TD_INC_DST_ADR | CY_DMA_TD_AUTO_EXEC_NEXT);
CyDmaTdSetAddress(DMA_1_TD[0], LO16((uint32)ADC_SAR_1_SAR_WRK0_PTR), LO16((uint32)datos));
CyDmaChSetInitialTd(DMA_1_Chan, DMA_1_TD[0]);
CyDmaChEnable(DMA_1_Chan, 1);
}


CY_ISR(Adquisicion){   
    //Se ingresa a esta rutina cuando el DMA termina la transacción 
    //Se desabilita el ADC para parar la conversión
    ADC_SAR_Seq_1_Stop();
    flag = 1;
    //Se habilita el canal DMA para la proxima transacción
    CyDmaChEnable(DMA_1_Chan, 1);
    isr_1_ClearPending();  
}


/*******************************************************************************
* Function Name: RxIsr
********************************************************************************
*
* Summary:
*  Interrupt Service Routine for RX portion of the UART
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
CY_ISR(RxIsr)
{
    uint8 rxStatus;         
    uint8 rxData;           
    
    do
    {
        /* Read receiver status register */
        rxStatus = UART_RXSTATUS_REG;

        if((rxStatus & (UART_RX_STS_BREAK      | UART_RX_STS_PAR_ERROR |
                        UART_RX_STS_STOP_ERROR | UART_RX_STS_OVERRUN)) != 0u)
        {
            /* ERROR handling. */
            errorStatus |= rxStatus & ( UART_RX_STS_BREAK      | UART_RX_STS_PAR_ERROR | 
                                        UART_RX_STS_STOP_ERROR | UART_RX_STS_OVERRUN);
        }
        
        if((rxStatus & UART_RX_STS_FIFO_NOTEMPTY) != 0u)
        {
            /* Read data from the RX data register */
            rxData = UART_RXDATA_REG;
            if (rxData == 'I')
            {
            flag_r = '1';
            }      
                       
            if(errorStatus == 0u)
            {
                /* Send data backward */
                //UART_TXDATA_REG = rxData;
            }
        }
    }while((rxStatus & UART_RX_STS_FIFO_NOTEMPTY) != 0u);
    //isr_rx_ClearPending(); 
}


/* [] END OF FILE */

